;$Id: shapelets_write.pro, v2$
;
; Copyright  2005 Richard Massey and Alexandre Refregier.
;
; This file is a part of the Shapelets analysis code.
; www.astro.caltech.edu/~rjm/shapelets/
;
; The Shapelets code is free software; you can redistribute it and/or
; modify it under the terms of the GNU General Public Licence as published
; by the Free Software Foundation; either version 2 of the Licence, or
; (at your option) any later version.
;
; The Shapelets code is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
; GNU General Public Licence for more details.
;
; You should have received a copy of the GNU General Public Licence
; along with the Shapelets code; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
;
; ************************************************************************
; ************************************************************************
;
; NAME:
;      SHAPELETS_WRITE
;
; PURPOSE:
;      Writes a shapelet coefficient catalogue of objects to disc.
;
; CATEGORY:
;      Data I/O.
;
; INPUTS:
;      STRUCTURE   - IDL shapecat or decomp structure to be stored.
;      FILENAME    - Desired name of saved file, without path or extension.
;
; OPTIONAL INPUTS
;      DESCRIPTION - String containing pertinent information.
;
; KEYWORD PARAMTERS:
;      SILENT      - Operates silently.
;      FULL_PATH   - Accepts the input filename as is (can be absolute or
;                    relative). Default behaviour is to prepend a path name
;                    with a relevant path obtained from from shapelets_paths.pro.
;
; OUTPUTS:
;      Shape information is written to disc.
;
; MODIFICATION HISTORY:
;      Jul 05 - Possibility of using DESCRIPTION keyword added by RM. 
;      Jul 05 - Default "IDL" filename adopted by RM.
;      Jul 05 - Renamed to shapelets_write by RM.
;      Jun 05 - Made able to cope with decomp structures by RM.
;      May 05 - FULL_PATH option added by RM.
;      May 04 - Shapelets_write_shapecat written by Richard Massey.
;-

pro shapelets_write, structure, filename, $
                     FULL_PATH=full_path, $
                     SILENT=silent,       $
	             _ref_extra = ex

COMPILE_OPT idl2

if not keyword_set(filename) then filename="idl"
if not shapelets_structure_type(structure,message=message) then message,message
if keyword_set(full_path) then filepath="" else filepath=shapelets_paths(2,silent=silent)
case message of
  "shapecat": begin
                if structure.polar then message,"Maybe should convert catalogue to Cartesian shapelets!",/info
                message,"Writing shapelet catalogue to "+filepath+filename+"."+structure.type,$
                        /info,noprint=silent
	      end
  "decomp": message,"Writing decomp structure to "+filepath+filename+"."+structure.type+". Restore using RESTORE.",$
                       /info,noprint=silent
  else: message,"Cannot save "+structure.type+"s with this routine!"
endcase

save,structure,filename=filepath+filename+"."+structure.type,_extra= ex
;if float(strmid(!version.release,0,3)) gt 6.1 then begin
;  save,structure,filename=filepath+filename+"."+structure.type,description=decription
;endif else begin
;  save,structure,filename=filepath+filename+"."+structure.type
;endelse

end
